@@ -6,6 +6,7 @@ use fuel_crypto::Hasher;
 use fuel_gql_client::client::schema::coin::Coin;
 use fuel_tx::{Address, AssetId, Bytes64, Input, Output, Receipt, Transaction, UtxoId, Witness};
 use fuel_vm::crypto::secp256k1_sign_compact_recoverable;
+use fuels_core::errors::Error;
 use secp256k1::{PublicKey, Secp256k1, SecretKey};
 use std::{fmt, io};
 use thiserror::Error;
@@ -24,7 +25,7 @@ use thiserror::Error;
 /// use secp256k1::SecretKey;
 /// use rand::{rngs::StdRng, RngCore, SeedableRng};
 /// use fuels_signers::provider::Provider;
-/// use fuels_signers::util::test_helpers::setup_test_provider;
+/// use fuels_test_helpers::setup_test_provider;
 ///
 /// async fn foo() -> Result<(), Box<dyn std::error::Error>> {
 ///   // Generate your secret key
@@ -86,6 +87,12 @@ pub enum WalletError {
     ProviderError(#[from] ProviderError),
 }
 
+impl From<WalletError> for Error {
+    fn from(e: WalletError) -> Self {
+        Error::WalletError(e.to_string())
+    }
+}
+
 impl Wallet {
     pub fn new_from_private_key(
         private_key: SecretKey,
@@ -115,9 +122,7 @@ impl Wallet {
     /// ```
     /// use fuels_signers::provider::Provider;
     /// use fuels_signers::{LocalWallet, Signer};
-    /// use fuels_signers::util::test_helpers::{
-    ///     setup_address_and_coins, setup_test_provider,
-    /// };
+    /// use fuels_test_helpers::{setup_address_and_coins, setup_test_provider};
     /// use fuel_tx::{Bytes32, AssetId, Input, Output, UtxoId};
     /// use rand::{rngs::StdRng, RngCore, SeedableRng};
     /// use secp256k1::SecretKey;
